==> openGion_dev_5.6.3.0.zip: opengion/uap/webapps/gf/src/org/opengion/hayabusa/db/CellRenderer.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.db;

/**
 * DBColumn インターフェースで使用される データ表示用のインターフェースです。
 * 適切な実装(サブクラス)を DBColumn に与えることで，データ表示方法を適宜
 * 切り替えることが出来ます。
 *
 * @og.rev 4.0.0 (2006/10/30) 新規追加
 * @og.group データ編集
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public interface CellRenderer {

	/**
	 * データの表示/編集用文字列を返します。
	 *
	 * @param   value 値
	 *
	 * @return  データの表示/編集用文字列
	 */
	String getValue( String value ) ;

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。
	 *
	 * @param   row   行番号
	 * @param   value 値
	 *
	 * @return  データ表示/編集用の文字列
	 */
	String getValue( int row,String value ) ;

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return  DBCellオブジェクト
	 */
	CellRenderer newInstance( DBColumn clm );
}

==> openGion_dev_5.10.23.0.zip: opengion/uap/webapps/gf/src/org/opengion/hayabusa/db/CellRenderer.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.db;

/**
 * DBColumn インターフェースで使用される データ表示用のインターフェースです。
 * 適切な実装(サブクラス)を DBColumn に与えることで，データ表示方法を適宜
 * 切り替えることが出来ます。
 *
 * @og.rev 4.0.0.0 (2006/10/30) 新規追加
 * @og.group データ編集
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public interface CellRenderer {

	/**
	 * データの表示/編集用文字列を返します。
	 *
	 * @param   value 値
	 *
	 * @return  データの表示/編集用文字列
	 */
	String getValue( String value ) ;

	/**
	 * name属性を変えた、データ表示/編集用のHTML文字列を作成します。
	 * テーブル上の name に 行番号を付加して、名前_行番号 で登録するキーを作成し,
	 * リクエスト情報を１つ毎のフィールドで処理できます。
	 *
	 * @param   row   行番号
	 * @param   value 値
	 *
	 * @return  データ表示/編集用の文字列
	 */
	String getValue( int row,String value ) ;

	/**
	 * 各オブジェクトから自分のインスタンスを返します。
	 * 自分自身をキャッシュするのか、新たに作成するのかは、各サブクラスの実装に
	 * まかされます。
	 *
	 * @og.rev 3.1.1.1 (2003/04/03) 各オブジェクトから自分のインスタンスを返すファクトリメソッドを追加。
	 *
	 * @param	clm	DBColumnオブジェクト
	 *
	 * @return  DBCellオブジェクト
	 */
	CellRenderer newInstance( DBColumn clm );
}
